# ailia SDK

SDK for optimized running of many popular neural networks on multiple platform

<img src="ailia_logo.png" width=256px>

## About ailia SDK

[ailia SDK](https://ailia.jp/en/) is a cross-platform high speed inference SDK. The ailia SDK provides a consistent C++ API on Windows, Mac, Linux, iOS, Android, Jetson and RaspberryPi. It supports Unity, Python and JNI for efficient AI implementation. The ailia SDK makes great use of the GPU via Vulkan and Metal to serve accelerated computing.

<!--
## ailia SDK API

[C++ (JP)](https://axinc-ai.github.io/ailia-sdk/api/cpp/jp/)
-->

## ailia SDK Tutorial

[Python](https://medium.com/axinc-ai/ailia-sdk-tutorial-python-ea29ae990cf6)

[Unity](https://medium.com/axinc-ai/ailia-sdk-tutorial-unity-54f2a8155b8f)

[C++](https://medium.com/axinc-ai/ailia-sdk-tutorial-c-75e59bbefffe)

## ailia SDK Sample projects

[Xcode](https://github.com/axinc-ai/ailia-xcode)

[Android Studio](https://github.com/axinc-ai/ailia-android-studio)

[Android NDK](https://github.com/axinc-ai/ailia-android-ndk)

## ailia Models

[Python](https://github.com/axinc-ai/ailia-models)

[Unity](https://github.com/axinc-ai/ailia-models-unity)

[C++](https://github.com/axinc-ai/ailia-models-cpp)

## Contact

[ax Inc.](https://axinc.jp/en/)

